WidgetCoordinates class

Constructors

WidgetCoordinates(int topLeftX, int topLeftY, int bottomRightX, int bottomRightY)
const

Properties

bottomRightX int
final
bottomRightY int
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topLeftX int
final
topLeftY int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override